Module beamlit.models.request_total_by_origin_metric_request_total_by_origin_and_code
=====================================================================================

Classes
-------

`RequestTotalByOriginMetricRequestTotalByOriginAndCode()`
:   Request total by origin and code
    
    Method generated by attrs for class RequestTotalByOriginMetricRequestTotalByOriginAndCode.

    ### Static methods

    `from_dict(src_dict: dict[str, typing.Any]) ‑> ~T`
    :

    ### Instance variables

    `additional_keys: list[str]`
    :

    `additional_properties: dict[str, typing.Any]`
    :

    ### Methods

    `to_dict(self) ‑> dict[str, typing.Any]`
    :